# (C) 2004-2006 Veit Wahlich <cru |at| zodia |dot| de>
# Released under the terms of the General Public License.
# Part of the Perl Script Pages. See POD for more information.

package PSP::CGI::Info;
our $VERSION='0.7';

use warnings;
use strict;
use Exporter;

our(@ISA,@EXPORT);
@ISA=qw(Exporter);
@EXPORT=qw(clientIP scriptURI requestURI documentRoot);

=head1 NAME

PSP::CGI::Info - provides function interface CGI environment variables.


=head1 SYNOPSIS

	use PSP::CGI::Info;
	my $clientIP = clientIP();
	my $scriptURI = scriptURI();
	my $requestURI = requestURI();
	my $documentRoot = documentRoot();

=head1 DESCRIPTION

This simple module does nothing but providing a nicer interface for working
with the most important CGI environment variables.
This module was created as a companion to the Perl Script Pages Engine.
See L<PSP::Engine> for more information.


=head1 OVERVIEW


=head2 Exported Functions

=over

=item clientIP

Returns the client's IP address, if provided by the web server, in dotted
decimals format.
See L</"clientIP function"> for details.

=item scriptURI

Returns the complete URI requested by the client, if provided by the web server.
See L</"scriptURI function"> for details.

=item requestURI

Returns the local part of the URI the client requested, if provided by the web
server.
See L</"requestURI function"> for details.

=item documentRoot

Returns the web server's/web virtual host's document root directory, if
provided by the web server.
See L</"documentRoot function"> for details.

=back


=head1 SYNTAX


=head2 clientIP Function

Returns the client's IP address, if provided by the web server, in dotted
decimals format.

	use PSP::CGI::Info;
	
	my $clientIP = clientIP();

This function is exported automatically.

=head3 Required Parameters

None.

=head3 Optional Parameters

None.

=head3 Return Values

=over

=item $clientIP

The client's IP address in dotted decimals format, or undef if not provided by
the web server.

=back

=cut
sub clientIP{
	return($ENV{REMOTE_ADDR});
}


=head2 scriptURI Function

Returns the complete URI requested by the client, if provided by the web server.

	use PSP::CGI::Info;
	
	my $scriptURI = scriptURI();

This function is exported automatically.

=head3 Required Parameters

None.

=head3 Optional Parameters

None.

=head3 Return Values

=over

=item $scriptURI

The complete URI requested by the client, i.e. "http://foo/bar.psp", or undef
if not provided by the web server.

=back

=cut
sub scriptURI{
	return($ENV{SCRIPT_NAME});
}


=head2 requestURI Function

Returns the local part of the URI the client requested, if provided by the web
server.

	use PSP::CGI::Info;
	
	my $requestURI = requestURI();

This function is exported automatically.

=head3 Required Parameters

None.

=head3 Optional Parameters

None.

=head3 Return Values

=over

=item $requestURI

The local part of he URI requested by the client, i.e. "/foo/bar.psp", or undef
if not provided by the web server.

=back

=cut
sub requestURI{
	return($ENV{REQUEST_URI});
}


=head2 documentRoot Function

Returns the web server's/web virtual host's document root directory, if
provided by the web server.

	use PSP::CGI::Info;
	
	my $documentRoot = documentRoot();

This function is exported automatically.

=head3 Required Parameters

None.

=head3 Optional Parameters

None.

=head3 Return Values

=over

=item $documentRoot

The web server's/web virtual host's document root directory, or undef if not
provided by the web server.

=back

=cut
sub documentRoot{
	return($ENV{DOCUMENT_ROOT});
}

1;


=head1 AUTHOR

Veit Wahlich

E-Mail: cru |at| zodia |dot| de

WWW: L<http://home.ircnet.de/cru/>


=head1 VERSION

v0.7
Wednesday, 18 January 2006


=head1 COPYRIGHT/LICENSE

Copyright 2004-2006 Veit Wahlich

This software is distributed as free (libre) software under the terms of the
GNU General Public License, version 2 E<lt>L<http://www.gnu.org/copyleft/gpl.html>E<gt>.
The author disclaims responsibility of any damage or harm caused directly or
indirectly by usage of this software. Use only at your own risk.
